﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:lx="http://www.landxml.org/schema/LandXML-1.0" xmlns:msxsl="urn:schemas-microsoft-com:xslt" xmlns:landUtils="http://www.autodesk.com/land/civil/vcedit" xmlns:earthworkUtils="urn:schemas-earth" xmlns:lxml="urn:lx_utils">
  <!--Description:Earthwork volumes report-->
  <!--CreatedBy:Autodesk Inc. -->
  <!--DateCreated:04/20/2004 -->
  <!--LastModifiedBy:Autodesk Inc. -->
  <!--DateModified:04/20/2004 -->
  <!--OutputExtension:html -->
  <xsl:output method="html" encoding="UTF-8" />
  <!-- ==== JavaScript Includes ==== -->
  <xsl:include href="../../scripts/NumberFormatting.xsl" />
  <xsl:include href="../../scripts/DK/StationFormatting_DK.xsl" />
  <!-- ============================= -->
  <xsl:param name="SourceAreaUnit" select="AeccEarthworkXML/Settings/Area/@unit" />
  <xsl:param name="SourceVolumeUnit" select="AeccEarthworkXML/Settings/Volume/@unit" />
  <xsl:param name="Surface.2D_Area.unit">default</xsl:param>
  <xsl:param name="Surface.2D_Area.precision">0.00</xsl:param>
  <xsl:param name="Surface.2D_Area.rounding">normal</xsl:param>
  <xsl:param name="Earthwork.Volume.unit">default</xsl:param>
  <xsl:param name="Earthwork.Volume.precision">0.00</xsl:param>
  <xsl:param name="Earthwork.Volume.rounding">normal</xsl:param>
  <xsl:template match="/">
    <html>
      <head>
        <title>Materiale rapport <xsl:value-of select="//lx:Alignment/@name" /></title>
      </head>
      <body>
        <div style="width:7in">
          <h1 align="center">Masse rapport</h1>
          <table border="0" cellspacing="0" cellpadding="0">
            <tr>
              <td>
                <h3>
									Tegning:  <xsl:value-of select="AeccEarthworkXML/Project/@name" /></h3>
              </td>
            </tr>
            <tr>
              <td>Linieføring:  <xsl:value-of select=".//Alignment/@name" /></td>
            </tr>
            <tr>
              <td>Sektionsgrp.:  <xsl:value-of select=".//Alignment/CrossSects/@name" /></td>
            </tr>
            <tr>
              <xsl:variable name="stationStart" select=".//Alignment/CrossSects/@startStaEq" />
              <td>Start station:  <xsl:value-of select="landUtils:getFormattedStation(string($stationStart))" /></td>
            </tr>
            <tr>
              <xsl:variable name="stationEnd" select=".//Alignment/CrossSects/@endStaEq" />
              <td>Slut station:  <xsl:value-of select="landUtils:getFormattedStation(string($stationEnd))" /></td>
            </tr>
          </table>
          <br />
          <table bordercolor="black" border="1" cellspacing="0" cellpadding="3" width="98%" align="center">
            <tr style="font-size:12pt;font-family:Verdana">
              <th />
              <th>Arealtype</th>
              <th>Areal</th>
              <th>Vol.</th>
              <th>Akk. Vol.</th>
              <th>Masse</th>
            </tr>
            <tr>
              <th />
              <th />
              <xsl:choose>
                <xsl:when test="$Surface.2D_Area.unit='default'">
                  <xsl:choose>
                    <xsl:when test="$SourceAreaUnit='square foot'">
                      <th>Sq.ft.</th>
                    </xsl:when>
                    <xsl:when test="$SourceAreaUnit='square meter'">
                      <th>m²</th>
                    </xsl:when>
                  </xsl:choose>
                </xsl:when>
                <xsl:when test="$Surface.2D_Area.unit='square foot'">
                  <th>Sq.ft.</th>
                </xsl:when>
                <xsl:when test="$Surface.2D_Area.unit='square meter'">
                  <th>m²</th>
                </xsl:when>
              </xsl:choose>
              <xsl:choose>
                <xsl:when test="$Earthwork.Volume.unit='default'">
                  <xsl:choose>
                    <xsl:when test="$SourceVolumeUnit='cubic foot'">
                      <th>Cu.ft.</th>
                    </xsl:when>
                    <xsl:when test="$SourceVolumeUnit='cubic meter'">
                      <th>m³</th>
                    </xsl:when>
                    <xsl:when test="$SourceVolumeUnit='cubic yard'">
                      <th>Cu.yd.</th>
                    </xsl:when>
                  </xsl:choose>
                </xsl:when>
                <xsl:when test="$Earthwork.Volume.unit='cubic foot'">
                  <th>Cu.ft.</th>
                </xsl:when>
                <xsl:when test="$Earthwork.Volume.unit='cubic meter'">
                  <th>m³</th>
                </xsl:when>
                <xsl:when test="$Earthwork.Volume.unit='cubic yard'">
                  <th>Cu.yd.</th>
                </xsl:when>
              </xsl:choose>
              <xsl:choose>
                <xsl:when test="$Earthwork.Volume.unit='default'">
                  <xsl:choose>
                    <xsl:when test="$SourceVolumeUnit='cubic foot'">
                      <th>Cu.ft.</th>
                    </xsl:when>
                    <xsl:when test="$SourceVolumeUnit='cubic meter'">
                      <th>m³</th>
                    </xsl:when>
                    <xsl:when test="$SourceVolumeUnit='cubic yard'">
                      <th>Cu.yd.</th>
                    </xsl:when>
                  </xsl:choose>
                </xsl:when>
                <xsl:when test="$Earthwork.Volume.unit='cubic foot'">
                  <th>Cu.ft.</th>
                </xsl:when>
                <xsl:when test="$Earthwork.Volume.unit='cubic meter'">
                  <th>m³</th>
                </xsl:when>
                <xsl:when test="$Earthwork.Volume.unit='cubic yard'">
                  <th>Cu.yd.</th>
                </xsl:when>
              </xsl:choose>
              <xsl:choose>
                <xsl:when test="$Earthwork.Volume.unit='default'">
                  <xsl:choose>
                    <xsl:when test="$SourceVolumeUnit='cubic foot'">
                      <th>Cu.ft.</th>
                    </xsl:when>
                    <xsl:when test="$SourceVolumeUnit='cubic meter'">
                      <th>m³</th>
                    </xsl:when>
                    <xsl:when test="$SourceVolumeUnit='cubic yard'">
                      <th>Cu.yd.</th>
                    </xsl:when>
                  </xsl:choose>
                </xsl:when>
                <xsl:when test="$Earthwork.Volume.unit='cubic foot'">
                  <th>Cu.ft.</th>
                </xsl:when>
                <xsl:when test="$Earthwork.Volume.unit='cubic meter'">
                  <th>m³</th>
                </xsl:when>
                <xsl:when test="$Earthwork.Volume.unit='cubic yard'">
                  <th>Cu.yd.</th>
                </xsl:when>
              </xsl:choose>
            </tr>
            <xsl:for-each select="AeccEarthworkXML">
              <xsl:for-each select="//Alignment/CrossSects">
                <xsl:for-each select="./CrossSect">
                  <tr style="font-size:10pt;font-family:Verdana">
                    <xsl:variable name="station" select="@staEq" />
                    <td align="right">Station: 
											<xsl:value-of select="landUtils:getFormattedStation(string($station))" /></td>
                  </tr>
                  <xsl:variable name="areaCut" select="@areaCut" />
                  <xsl:variable name="areaFill" select="@areaFill" />
                  <xsl:variable name="areaUsable" select="@areaUsable" />
                  <xsl:variable name="incVolCut" select="@volumeCut" />
                  <xsl:variable name="incVolFill" select="@volumeFill" />
                  <xsl:variable name="incVolUsable" select="@volumeUsable" />
                  <xsl:variable name="cumVolCut" select="@cumVolumeCut" />
                  <xsl:variable name="cumVolFill" select="@cumVolumeFill" />
                  <xsl:variable name="cumVolUsable" select="@cumVolumeUsable" />
                  <xsl:variable name="massHaul" select="@massHaul" />
                  <xsl:for-each select="./CrossSectAreas/CrossSectArea">
                    <xsl:variable name="Area" select="@area" />
                    <xsl:variable name="IncVol" select="@volume" />
                    <xsl:variable name="cumVol" select="@cumVolume" />
                    <tr style="font-size:10pt;font-family:Verdana">
                      <td />
                      <td align="left">
                        <xsl:value-of select="@name" />
                      </td>
                      <td align="left">
                        <xsl:value-of select="landUtils:FormatNumber(string($Area), string($SourceAreaUnit), string($Surface.2D_Area.unit), string($Surface.2D_Area.precision), string($Surface.2D_Area.rounding))" />
                      </td>
                      <xsl:choose>
                        <xsl:when test="@volume">
                          <td align="left">
                            <xsl:value-of select="landUtils:FormatNumber(string($IncVol), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))" />
                          </td>
                        </xsl:when>
                        <xsl:otherwise>
                          <td>NA</td>
                        </xsl:otherwise>
                      </xsl:choose>
                      <xsl:choose>
                        <xsl:when test="@cumVolume">
                          <td align="left">
                            <xsl:value-of select="landUtils:FormatNumber(string($cumVol), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))" />
                          </td>
                        </xsl:when>
                        <xsl:otherwise>
                          <td>NA</td>
                        </xsl:otherwise>
                      </xsl:choose>
                    </tr>
                  </xsl:for-each>
                  <tr style="font-size:10pt;font-family:Verdana">
                    <td />
                    <td align="left">Tilpasset cut</td>
                    <td align="left">
                      <xsl:value-of select="landUtils:FormatNumber(string($areaCut), string($SourceAreaUnit), string($Surface.2D_Area.unit), string($Surface.2D_Area.precision), string($Surface.2D_Area.rounding))" />
                    </td>
                    <xsl:choose>
                      <xsl:when test="@volumeCut">
                        <td align="left">
                          <xsl:value-of select="landUtils:FormatNumber(string($incVolCut), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))" />
                        </td>
                      </xsl:when>
                      <xsl:otherwise>
                        <td>NA</td>
                      </xsl:otherwise>
                    </xsl:choose>
                    <xsl:choose>
                      <xsl:when test="@cumVolumeCut">
                        <td align="left">
                          <xsl:value-of select="landUtils:FormatNumber(string($cumVolCut), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))" />
                        </td>
                      </xsl:when>
                      <xsl:otherwise>
                        <td>NA</td>
                      </xsl:otherwise>
                    </xsl:choose>
                  </tr>
                  <tr style="font-size:10pt;font-family:Verdana">
                    <td />
                    <td align="left">Tilpasset genbrug</td>
                    <td align="left">
                      <xsl:value-of select="landUtils:FormatNumber(string($areaUsable), string($SourceAreaUnit), string($Surface.2D_Area.unit), string($Surface.2D_Area.precision), string($Surface.2D_Area.rounding))" />
                    </td>
                    <xsl:choose>
                      <xsl:when test="@volumeUsable">
                        <td align="left">
                          <xsl:value-of select="landUtils:FormatNumber(string($incVolUsable), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))" />
                        </td>
                      </xsl:when>
                      <xsl:otherwise>
                        <td>NA</td>
                      </xsl:otherwise>
                    </xsl:choose>
                    <xsl:choose>
                      <xsl:when test="@cumVolumeUsable">
                        <td align="left">
                          <xsl:value-of select="landUtils:FormatNumber(string($cumVolUsable), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))" />
                        </td>
                      </xsl:when>
                      <xsl:otherwise>
                        <td>NA</td>
                      </xsl:otherwise>
                    </xsl:choose>
                  </tr>
                  <tr style="font-size:10pt;font-family:Verdana">
                    <td />
                    <td align="left">Tilpasset fill</td>
                    <td align="left">
                      <xsl:value-of select="landUtils:FormatNumber(string($areaFill), string($SourceAreaUnit), string($Surface.2D_Area.unit), string($Surface.2D_Area.precision), string($Surface.2D_Area.rounding))" />
                    </td>
                    <xsl:choose>
                      <xsl:when test="@volumeFill">
                        <td align="left">
                          <xsl:value-of select="landUtils:FormatNumber(string($incVolFill), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))" />
                        </td>
                      </xsl:when>
                      <xsl:otherwise>
                        <td>NA</td>
                      </xsl:otherwise>
                    </xsl:choose>
                    <xsl:choose>
                      <xsl:when test="@cumVolumeFill">
                        <td align="left">
                          <xsl:value-of select="landUtils:FormatNumber(string($cumVolFill), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))" />
                        </td>
                      </xsl:when>
                      <xsl:otherwise>
                        <td>NA</td>
                      </xsl:otherwise>
                    </xsl:choose>
                  </tr>
                  <tr style="font-size:10pt;font-family:Verdana">
                    <td />
                    <td />
                    <td />
                    <td />
                    <td />
                    <xsl:choose>
                      <xsl:when test="@massHaul">
                        <td align="left">
                          <xsl:value-of select="landUtils:FormatNumber(string($massHaul), string($SourceVolumeUnit), string($Earthwork.Volume.unit), string($Earthwork.Volume.precision), string($Earthwork.Volume.rounding))" />
                        </td>
                      </xsl:when>
                      <xsl:otherwise>
                        <td>NA</td>
                      </xsl:otherwise>
                    </xsl:choose>
                  </tr>
                </xsl:for-each>
              </xsl:for-each>
            </xsl:for-each>
          </table>
        </div>
      </body>
    </html>
  </xsl:template>
  <msxsl:script language="vbScript" implements-prefix="earthworkUtils"><![CDATA[
function FormatVolume(numberStr, fromStr, toStr, precisionStr, roundingStr)

	dim numStr,fStr,tStr,pStr,rStr,origNumber,convNumber,precDepth,fixedDec,rNumber
	fStr = fromStr
	tStr = toStr
	pStr = precisionStr
	rStr = roundingStr
	
	numStr = numberStr


	origNumber = numStr
	
	convNumber = 0
	rNumber = numberStr
	
	' Do conversion if necessary
	if  (tStr = "default") then
		convNumber = origNumber
	else
		convNumber = ConvertVolume(origNumber, fStr, tStr)
	end if
	rNumber = FormatPrecision(convNumber, pStr, rStr)
	
	FormatVolume = CStr(rNumber)

end function

function ConvertVolume(num, fromStr, toStr)

	dim convNumber 
	dim numer 

	convNumber = num
	numer = num

	if(fromStr = "cubicFeet") then
		if(toStr = "cubicMeter") then
			convNumber = CubicFeetToMeters(numer)
		end if
	
	elseif(fromStr = "cubicMeter") then
		if(toStr = "cubicFeet") then
		
			convNumber = CubicMeterToFeet(numer)
		end if
	else
		convNumber = numer
	end if
	
	ConvertVolume = convNumber
end function


function CubicMeterToFeet(d)

	CubicMeterToFeet = d/(.3048^3)
end function

function CubicFeetToMeters(d)

	CubicFeetToMeters =  d * (.3048^3)
end function



]]></msxsl:script>
</xsl:stylesheet>