<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:gml="http://www.opengis.net/gml"
                xmlns:txdp="http://www.transxml.net/schema/dp/0.3"
                xmlns:txr="http://www.transxml.net/schema/ref/0.3"
                xmlns:txl="http://www.transxml.net/schema/txl/0.3"
                xmlns:c3d="Civil3D.QTO.Computation">
  <!--Description:Quantity Take-Off Report-->
  <!--CreatedBy:Autodesk Inc. -->
  <!--DateCreated:06/27/2008 -->
  <!--LastModifiedBy:Autodesk Inc. -->
  <!--DateCreated:06/27/2008 -->
  <!--OutputExtension:txt -->
  <xsl:import href="SharedLibs (TXT).xsl" />
  <xsl:output method="text" encoding="UTF-8"/>
  <!-- ============================= -->
  <xsl:template match="text()">
    <xsl:value-of select="."/>
  </xsl:template>
  <xsl:variable name="reportType" select="'itemized'" />
  <xsl:variable name="titleText" select="'Detaljeret lineær QTO rapport'" />
  <xsl:variable name="unitTypeFilter" select="'linear'"/>
  
  <!--Varibles of format-->

  <!--Width of the columns-->
  <xsl:variable name="colWidth1" select="15" />
  <xsl:variable name="colWidth2" select="60" />
  <xsl:variable name="colWidth3" select="10" />
  <xsl:variable name="colWidth4" select="4" />
  <xsl:variable name="colWidth5" select="15" />
  <xsl:variable name="colWidth6" select="12" />
  <xsl:variable name="colWidth7" select="12" />
  <xsl:variable name="colWidth8" select="12" />
  <xsl:variable name="colWidth9" select="12" />
  <xsl:variable name="colWidth10" select="20" />

  <xsl:variable name="spaceBetweenColumns" select="3"/>

  <xsl:variable name="lineWidth" select="$spaceBetweenColumns * 9 + $colWidth1 + $colWidth2 + $colWidth3 + $colWidth4 + $colWidth5 + $colWidth6 + $colWidth7 + $colWidth8 + $colWidth9 + $colWidth10 "/>
  
  <xsl:variable name="stationIndent" select="$spaceBetweenColumns * 5 + $colWidth1 + $colWidth2 + $colWidth3 + $colWidth4 + $colWidth5"/>
  <xsl:variable name="stationWidth" select="$spaceBetweenColumns + $colWidth6 + $colWidth7"/>
  <xsl:variable name="offsetWidth" select="$spaceBetweenColumns + $colWidth8 + $colWidth9"/>
                
  <xsl:template match="/">
    <!--the title of the table-->
    <xsl:call-template name="OutputTitle">
      <xsl:with-param name="lineLength" select="$lineWidth"/>
      <xsl:with-param name="titleText" select="$titleText"/>
    </xsl:call-template>

    <xsl:value-of select="$breakline"/>

    <!-- DesignProject Begin -->
    <xsl:for-each select="txdp:DesignProject">
      <!-- DesignProjectPayItemGroup Begin -->

      <!--header of the table-->
      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$stationIndent"/>
      </xsl:call-template>

      <xsl:call-template name="OutputCenterAlignedText">
        <xsl:with-param name="text" select="'Station'"/>
        <xsl:with-param name="columnWidth" select="$stationWidth"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputCenterAlignedText">
        <xsl:with-param name="text" select="'Offset'"/>
        <xsl:with-param name="columnWidth" select="$offsetWidth"/>
      </xsl:call-template>

      <xsl:value-of select="$breakline"/>
      
      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Elment'"/>
        <xsl:with-param name="columnWidth" select="$colWidth1"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Beskrivelse'"/>
        <xsl:with-param name="columnWidth" select="$colWidth2"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Antal'"/>
        <xsl:with-param name="columnWidth" select="$colWidth3"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Enhed'"/>
        <xsl:with-param name="columnWidth" select="$colWidth4"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Linjeføring'"/>
        <xsl:with-param name="columnWidth" select="$colWidth5"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Start'"/>
        <xsl:with-param name="columnWidth" select="$colWidth6"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Slut'"/>
        <xsl:with-param name="columnWidth" select="$colWidth7"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Start'"/>
        <xsl:with-param name="columnWidth" select="$colWidth8"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Slut'"/>
        <xsl:with-param name="columnWidth" select="$colWidth9"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Bemærkninger'"/>
        <xsl:with-param name="columnWidth" select="$colWidth10"/>
      </xsl:call-template>

      <xsl:value-of select="$breakline"/>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth1"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth2"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth3"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth4"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth5"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth6"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth7"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth8"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth9"/>
      </xsl:call-template>
      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth10"/>
      </xsl:call-template>

      <xsl:value-of select="$breakline"/>
      
      <xsl:for-each select="txdp:group/txdp:DesignProjectPayItemGroup">
        <!-- DesignProjectPayItem Begin -->
        <xsl:for-each select="txdp:item/txdp:DesignProjectPayItem[c3d:referenceInformation/c3d:unitType = $unitTypeFilter]">
          <!--the content of the table-->
          <xsl:for-each select="c3d:referenceBaseline/c3d:item">
            <!--content of table-->
            <xsl:call-template name="OutputLeftAlignedText">
              <xsl:with-param name="text" select="../..//txr:ReferencePayItem/txr:referencePayItemID"/>
              <xsl:with-param name="columnWidth" select="$colWidth1"/>
            </xsl:call-template>

            <xsl:call-template name="GenBlanks">
              <xsl:with-param name="count" select="$spaceBetweenColumns"/>
            </xsl:call-template>

            <xsl:call-template name="OutputLeftAlignedText">
              <xsl:with-param name="text" select="../..//txr:ReferencePayItem/gml:description"/>
              <xsl:with-param name="columnWidth" select="$colWidth2"/>
            </xsl:call-template>

            <xsl:call-template name="GenBlanks">
              <xsl:with-param name="count" select="$spaceBetweenColumns"/>
            </xsl:call-template>

            <xsl:call-template name="OutputLeftAlignedText">
              <xsl:with-param name="text" select="c3d:quantity"/>
              <xsl:with-param name="columnWidth" select="$colWidth3"/>
            </xsl:call-template>

            <xsl:call-template name="GenBlanks">
              <xsl:with-param name="count" select="$spaceBetweenColumns"/>
            </xsl:call-template>

            <xsl:call-template name="OutputLeftAlignedText">
              <xsl:with-param name="text" select="../..//txl:UnitOfMeasure/txl:unitOfMeasureID"/>
              <xsl:with-param name="columnWidth" select="$colWidth4"/>
            </xsl:call-template>

            <xsl:call-template name="GenBlanks">
              <xsl:with-param name="count" select="$spaceBetweenColumns"/>
            </xsl:call-template>

            <xsl:call-template name="OutputLeftAlignedText">
              <xsl:with-param name="text" select="c3d:baselineName"/>
              <xsl:with-param name="columnWidth" select="$colWidth5"/>
            </xsl:call-template>

            <xsl:call-template name="GenBlanks">
              <xsl:with-param name="count" select="$spaceBetweenColumns"/>
            </xsl:call-template>

            <xsl:call-template name="OutputLeftAlignedText">
              <xsl:with-param name="text" select="c3d:startStation"/>
              <xsl:with-param name="columnWidth" select="$colWidth6"/>
            </xsl:call-template>

            <xsl:call-template name="GenBlanks">
              <xsl:with-param name="count" select="$spaceBetweenColumns"/>
            </xsl:call-template>

            <xsl:call-template name="OutputLeftAlignedText">
              <xsl:with-param name="text" select="c3d:endStation"/>
              <xsl:with-param name="columnWidth" select="$colWidth7"/>
            </xsl:call-template>

            <xsl:call-template name="GenBlanks">
              <xsl:with-param name="count" select="$spaceBetweenColumns"/>
            </xsl:call-template>

            <xsl:call-template name="OutputLeftAlignedText">
              <xsl:with-param name="text" select="concat( c3d:startOffset, ' ', c3d:side)"/>
              <xsl:with-param name="columnWidth" select="$colWidth8"/>
            </xsl:call-template>

            <xsl:call-template name="GenBlanks">
              <xsl:with-param name="count" select="$spaceBetweenColumns"/>
            </xsl:call-template>

            <xsl:call-template name="OutputLeftAlignedText">
              <xsl:with-param name="text" select="concat( c3d:endOffset, ' ', c3d:side)"/>
              <xsl:with-param name="columnWidth" select="$colWidth9"/>
            </xsl:call-template>

            <xsl:call-template name="GenBlanks">
              <xsl:with-param name="count" select="$spaceBetweenColumns"/>
            </xsl:call-template>

            <xsl:call-template name="OutputLeftAlignedText">
              <xsl:with-param name="text" select="c3d:remarks"/>
              <xsl:with-param name="columnWidth" select="$colWidth10"/>
            </xsl:call-template>

            <xsl:value-of select="$breakline"/>
          </xsl:for-each>
        </xsl:for-each>
        <!-- DesignProjectPayItem End -->
      </xsl:for-each>
      <!-- DesignProjectPayItemGroup End -->
    </xsl:for-each>
    <!-- DesignProject End -->

  </xsl:template>



</xsl:stylesheet>

