﻿<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" 
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
                xmlns:gml="http://www.opengis.net/gml" 
                xmlns:txdp="http://www.transxml.net/schema/dp/0.3" 
                xmlns:txr="http://www.transxml.net/schema/ref/0.3" 
                xmlns:txl="http://www.transxml.net/schema/txl/0.3" 
                xmlns:c3d="Civil3D.QTO.Computation">
<!--This file define some common templates shared among the general txt xsl reports.-->
  
  <!-- Defien variables for breakline -->
  <xsl:variable name="breakline" select="'&#10;'" />
  <xsl:template name="GenTabs">
    <xsl:param name="count" select="1"/>
    <xsl:if test="$count > 0">
      <xsl:text>&#09;</xsl:text>
      <xsl:call-template name="GenTabs">
        <xsl:with-param name="count" select="$count - 1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <!--Generating Blanks-->
  <xsl:template name="GenBlanks">
    <xsl:param name="count" select="1"/>
    <xsl:if test="$count > 0">
      <xsl:text> </xsl:text>
      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$count - 1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <!--Outputing text, and add blanks to fill the specified width if needed-->
  <xsl:template name="OutputLeftAlignedText">
    <xsl:param name="text"/>
    <xsl:param name="columnWidth"/>
    <xsl:param name="stringLen" select="string-length($text)"/>
    <xsl:param name="rightBlanks" select="$columnWidth - $stringLen"/>
    <xsl:value-of select="$text"/>
    <xsl:call-template name="GenBlanks">
      <xsl:with-param name="count" select="$rightBlanks"/>
    </xsl:call-template>
  </xsl:template>
  
  <!--Outputing text, and add blanks to fill the specified width if needed-->
  <xsl:template name="OutputCenterAlignedText">
    <xsl:param name="text"/>
    <xsl:param name="columnWidth"/>
    <xsl:param name="stringLen" select="string-length($text)"/>
    <xsl:param name="leftBlanks" select="round (($columnWidth - $stringLen) div 2)"/>
    <xsl:param name="rightBlanks" select="$columnWidth - $stringLen - $leftBlanks"/>
    <xsl:call-template name="GenBlanks">
      <xsl:with-param name="count" select="$leftBlanks"/>
    </xsl:call-template>
    <xsl:value-of select="$text"/>
    <xsl:call-template name="GenBlanks">
      <xsl:with-param name="count" select="$rightBlanks"/>
    </xsl:call-template>

  </xsl:template>

  <!-- Output a split line every 5 lines and at the last line -->
  <xsl:template name="GenLineEvery5LinesOrAtTheEnd">
    <xsl:param name="lineLength"/>
    <xsl:if test="position() mod 5 = 0 or position() = last()">
      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$lineLength"/>
      </xsl:call-template>
      <xsl:value-of select="$breakline" />
    </xsl:if>
  </xsl:template>
  
  <xsl:template name="SplitLine">
    <xsl:param name="length" select="1"/>
    <xsl:if test="$length > 0">
      <xsl:text>-</xsl:text>
      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$length - 1"/>
      </xsl:call-template>
    </xsl:if>
  </xsl:template>

  <xsl:template name="OutputTitle">
    <xsl:param name="lineLength" />
    <xsl:param name="titleText" />
    <xsl:call-template name="OutputCenterAlignedText">
      <xsl:with-param name="text" select="$titleText"/>
      <xsl:with-param name="columnWidth" select="$lineLength"/>
    </xsl:call-template>

    <xsl:value-of select="$breakline"/>

    <xsl:variable   name="underline">
      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="string-length($titleText)"/>
      </xsl:call-template>
    </xsl:variable>
    
    <xsl:call-template name="OutputCenterAlignedText">
      <xsl:with-param name="text" select="$underline"/>
      <xsl:with-param name="columnWidth" select="$lineLength"/>
    </xsl:call-template>

  </xsl:template>

 
</xsl:stylesheet>
