<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:gml="http://www.opengis.net/gml"
                xmlns:txdp="http://www.transxml.net/schema/dp/0.3"
                xmlns:txr="http://www.transxml.net/schema/ref/0.3"
                xmlns:txl="http://www.transxml.net/schema/txl/0.3"
                xmlns:c3d="Civil3D.QTO.Computation">
  <!--Description:Quantity Take-Off Report-->
  <!--CreatedBy:Autodesk Inc. -->
  <!--DateCreated:06/27/2008 -->
  <!--LastModifiedBy:Autodesk Inc. -->
  <!--DateCreated:06/27/2008 -->
  <!--OutputExtension:txt -->
  <xsl:import href="SharedLibs (TXT).xsl" />
  <xsl:output method="text" encoding="UTF-8"/>
  <!-- ============================= -->
  <xsl:template match="text()">
    <xsl:value-of select="."/>
  </xsl:template>
  <xsl:variable name="reportType" select="'summary'" />
  <xsl:variable name="titleText" select="'Samlet QTO rapport'" />

  <!--Varibles of format-->

  <!--Width of the columns-->
  <xsl:variable name="colWidth1" select="15" />
  <xsl:variable name="colWidth2" select="60" />
  <xsl:variable name="colWidth3" select="10" />
  <xsl:variable name="colWidth4" select="4" />

  <xsl:variable name="spaceBetweenColumns" select="3"/>

  <xsl:variable name="lineWidth" select="$spaceBetweenColumns * 3 + $colWidth1 + $colWidth2 + $colWidth3 + $colWidth4 "/>

  <xsl:template match="/">
    <!--the title of the table-->
    <xsl:call-template name="OutputTitle">
      <xsl:with-param name="lineLength" select="$lineWidth"/>
      <xsl:with-param name="titleText" select="$titleText"/>
    </xsl:call-template>

    <xsl:value-of select="$breakline"/>

    <!-- DesignProject Begin -->
    <xsl:for-each select="txdp:DesignProject">
      <!-- DesignProjectPayItemGroup Begin -->

      <!--header of the table-->
      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Element'"/>
        <xsl:with-param name="columnWidth" select="$colWidth1"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Beskrivelse'"/>
        <xsl:with-param name="columnWidth" select="$colWidth2"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Antal'"/>
        <xsl:with-param name="columnWidth" select="$colWidth3"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="OutputLeftAlignedText">
        <xsl:with-param name="text" select="'Enhed'"/>
        <xsl:with-param name="columnWidth" select="$colWidth4"/>
      </xsl:call-template>

      <xsl:value-of select="$breakline"/>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth1"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth2"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth3"/>
      </xsl:call-template>

      <xsl:call-template name="GenBlanks">
        <xsl:with-param name="count" select="$spaceBetweenColumns"/>
      </xsl:call-template>

      <xsl:call-template name="SplitLine">
        <xsl:with-param name="length" select="$colWidth4"/>
      </xsl:call-template>

      <xsl:value-of select="$breakline"/>
      
      <xsl:for-each select="txdp:group/txdp:DesignProjectPayItemGroup">
        <!-- DesignProjectPayItem Begin -->
        <xsl:for-each select="txdp:item/txdp:DesignProjectPayItem">




          <!--content of table-->
          <xsl:call-template name="OutputLeftAlignedText">
            <xsl:with-param name="text" select=".//txr:ReferencePayItem/txr:referencePayItemID"/>
            <xsl:with-param name="columnWidth" select="$colWidth1"/>
          </xsl:call-template>

          <xsl:call-template name="GenBlanks">
            <xsl:with-param name="count" select="$spaceBetweenColumns"/>
          </xsl:call-template>

          <xsl:call-template name="OutputLeftAlignedText">
            <xsl:with-param name="text" select=".//txr:ReferencePayItem/gml:description"/>
            <xsl:with-param name="columnWidth" select="$colWidth2"/>
          </xsl:call-template>

          <xsl:call-template name="GenBlanks">
            <xsl:with-param name="count" select="$spaceBetweenColumns"/>
          </xsl:call-template>

          <xsl:call-template name="OutputLeftAlignedText">
            <xsl:with-param name="text" select="txdp:estimatedQuantity"/>
            <xsl:with-param name="columnWidth" select="$colWidth3"/>
          </xsl:call-template>

          <xsl:call-template name="GenBlanks">
            <xsl:with-param name="count" select="$spaceBetweenColumns"/>
          </xsl:call-template>

          <xsl:call-template name="OutputLeftAlignedText">
            <xsl:with-param name="text" select=".//txl:UnitOfMeasure/txl:unitOfMeasureID"/>
            <xsl:with-param name="columnWidth" select="$colWidth4"/>
          </xsl:call-template>

          <xsl:value-of select="$breakline"/>
          
        </xsl:for-each>
        <!-- DesignProjectPayItem End -->
      </xsl:for-each>
      <!-- DesignProjectPayItemGroup End -->
    </xsl:for-each>
    <!-- DesignProject End -->

  </xsl:template>



</xsl:stylesheet>

